==> libminigui-3.2.3.tar.gz: libminigui-3.2.3/src/sysres/icon/_icon_inner_res.c <==
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */
//inner list file
//create by inner-trans

#ifdef _MGINCORE_RES

//include files

#ifdef _MGLF_RDR_FLAT
extern unsigned char _mgir_ico_excalmatory_flat_data[]; //icon/excalmatory-flat.ico.c 
#endif

extern unsigned char _mgir_ico_excalmatory_data[]; //icon/excalmatory.ico.c 

#ifdef _MGLF_RDR_FLAT
extern unsigned char _mgir_ico_failed_flat_data[]; //icon/failed-flat.ico.c 
#endif

extern unsigned char _mgir_ico_failed_data[]; //icon/failed.ico.c 

#ifdef _MGLF_RDR_FLAT
extern unsigned char _mgir_ico_folder_flat_data[]; //icon/folder-flat.ico.c 
#endif

extern unsigned char _mgir_ico_folder_data[]; //icon/folder.ico.c 


#ifdef _MGLF_RDR_FLAT
extern unsigned char _mgir_ico_fold_flat_data[]; //icon/fold-flat.ico.c 
#endif

extern unsigned char _mgir_ico_fold_data[]; //icon/fold.ico.c 

#ifdef _MGLF_RDR_FLAT
extern unsigned char _mgir_ico_form_flat_data[]; //icon/form-flat.ico.c 
#endif


extern unsigned char _mgir_ico_form_data[]; //icon/form.ico.c 

#ifdef _MGLF_RDR_FLAT
extern unsigned char _mgir_ico_help_flat_data[]; //icon/help-flat.ico.c 
#endif

extern unsigned char _mgir_ico_help_data[]; //icon/help.ico.c 

#ifdef _MGLF_RDR_FLAT
extern unsigned char _mgir_ico_textfile_flat_data[]; //icon/textfile-flat.ico.c 
#endif

extern unsigned char _mgir_ico_textfile_data[]; //icon/textfile.ico.c 

#ifdef _MGLF_RDR_FLAT
extern unsigned char _mgir_ico_unfold_flat_data[]; //icon/unfold-flat.ico.c 
#endif

extern unsigned char _mgir_ico_unfold_data[]; //icon/unfold.ico.c 

#ifdef _MGLF_RDR_FLAT
extern unsigned char _mgir_ico_warning_flat_data[]; //icon/warning-flat.ico.c 
#endif

extern unsigned char _mgir_ico_warning_data[]; //icon/warning.ico.c 
//declear arrays
static INNER_RES __mgir_icon_inner_res[]={

#ifdef _MGLF_RDR_FLAT
	{ 0x32F227B, (void*)_mgir_ico_excalmatory_flat_data, 1078, "ico"}, //icon/excalmatory-flat.ico.c
#endif

	{ 0x98577B, (void*)_mgir_ico_excalmatory_data, 3638, "ico"}, //icon/excalmatory.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x975743, (void*)_mgir_ico_failed_flat_data, 1078, "ico"}, //icon/failed-flat.ico.c
#endif
	{ 0x191B83, (void*)_mgir_ico_failed_data, 3638, "ico"}, //icon/failed.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x977D73, (void*)_mgir_ico_folder_flat_data, 1078, "ico"}, //icon/folder-flat.ico.c
#endif

	{ 0x1931B3, (void*)_mgir_ico_folder_data, 1078, "ico"}, //icon/folder.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x4BF2B3, (void*)_mgir_ico_fold_flat_data, 1078, "ico"}, //icon/fold-flat.ico.c
#endif

	{ 0xCD4D3, (void*)_mgir_ico_fold_data, 1078, "ico"}, //icon/fold.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x4B0223, (void*)_mgir_ico_form_flat_data, 3638, "ico"}, //icon/form-flat.ico.c
#endif

	{ 0xC2443, (void*)_mgir_ico_form_data, 3638, "ico"}, //icon/form.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x4BCBA3, (void*)_mgir_ico_help_flat_data, 1078, "ico"}, //icon/help-flat.ico.c
#endif

	{ 0xCEDC3, (void*)_mgir_ico_help_data, 3638, "ico"}, //icon/help.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x12F9D03, (void*)_mgir_ico_textfile_flat_data, 1078, "ico"}, //icon/textfile-flat.ico.c
#endif

	{ 0x330483, (void*)_mgir_ico_textfile_data, 1078, "ico"}, //icon/textfile.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x97F30B, (void*)_mgir_ico_unfold_flat_data, 1078, "ico"}, //icon/unfold-flat.ico.c
#endif

	{ 0x19BFCB, (void*)_mgir_ico_unfold_data, 1078, "ico"}, //icon/unfold.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0xC8AC63, (void*)_mgir_ico_warning_flat_data, 1078, "ico"}, //icon/warning-flat.ico.c
#endif

	{ 0x257123, (void*)_mgir_ico_warning_data, 3638, "ico"}, //icon/warning.ico.c
};

#endif // _MGINCORE_RES

==> libminigui-4.0.2.tar.gz: libminigui-4.0.2/src/sysres/icon/_icon_inner_res.c <==
///////////////////////////////////////////////////////////////////////////////
//
//                          IMPORTANT NOTICE
//
// The following open source license statement does not apply to any
// entity in the Exception List published by FMSoft.
//
// For more information, please visit:
//
// https://www.fmsoft.cn/exception-list
//
//////////////////////////////////////////////////////////////////////////////
/*
 *   This file is part of MiniGUI, a mature cross-platform windowing 
 *   and Graphics User Interface (GUI) support system for embedded systems
 *   and smart IoT devices.
 * 
 *   Copyright (C) 2002~2018, Beijing FMSoft Technologies Co., Ltd.
 *   Copyright (C) 1998~2002, WEI Yongming
 * 
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *   Or,
 * 
 *   As this program is a library, any link to this program must follow
 *   GNU General Public License version 3 (GPLv3). If you cannot accept
 *   GPLv3, you need to be licensed from FMSoft.
 * 
 *   If you have got a commercial license of this program, please use it
 *   under the terms and conditions of the commercial license.
 * 
 *   For more information about the commercial license, please refer to
 *   <http://www.minigui.com/en/about/licensing-policy/>.
 */
//inner list file
//create by inner-trans

#ifdef _MGINCORE_RES

//include files

#ifdef _MGLF_RDR_FLAT
extern const unsigned char _mgir_ico_excalmatory_flat_data[]; //icon/excalmatory-flat.ico.c 
#endif

extern const unsigned char _mgir_ico_excalmatory_data[]; //icon/excalmatory.ico.c 

#ifdef _MGLF_RDR_FLAT
extern const unsigned char _mgir_ico_failed_flat_data[]; //icon/failed-flat.ico.c 
#endif

extern const unsigned char _mgir_ico_failed_data[]; //icon/failed.ico.c 

#ifdef _MGLF_RDR_FLAT
extern const unsigned char _mgir_ico_folder_flat_data[]; //icon/folder-flat.ico.c 
#endif

extern const unsigned char _mgir_ico_folder_data[]; //icon/folder.ico.c 


#ifdef _MGLF_RDR_FLAT
extern const unsigned char _mgir_ico_fold_flat_data[]; //icon/fold-flat.ico.c 
#endif

extern const unsigned char _mgir_ico_fold_data[]; //icon/fold.ico.c 

#ifdef _MGLF_RDR_FLAT
extern const unsigned char _mgir_ico_form_flat_data[]; //icon/form-flat.ico.c 
#endif


extern const unsigned char _mgir_ico_form_data[]; //icon/form.ico.c 

#ifdef _MGLF_RDR_FLAT
extern const unsigned char _mgir_ico_help_flat_data[]; //icon/help-flat.ico.c 
#endif

extern const unsigned char _mgir_ico_help_data[]; //icon/help.ico.c 

#ifdef _MGLF_RDR_FLAT
extern const unsigned char _mgir_ico_textfile_flat_data[]; //icon/textfile-flat.ico.c 
#endif

extern const unsigned char _mgir_ico_textfile_data[]; //icon/textfile.ico.c 

#ifdef _MGLF_RDR_FLAT
extern const unsigned char _mgir_ico_unfold_flat_data[]; //icon/unfold-flat.ico.c 
#endif

extern const unsigned char _mgir_ico_unfold_data[]; //icon/unfold.ico.c 

#ifdef _MGLF_RDR_FLAT
extern const unsigned char _mgir_ico_warning_flat_data[]; //icon/warning-flat.ico.c 
#endif

extern const unsigned char _mgir_ico_warning_data[]; //icon/warning.ico.c 

//declear arrays
static const INNER_RES __mgir_icon_inner_res[]={

#ifdef _MGLF_RDR_FLAT
	{ 0x32F227B, (void*)_mgir_ico_excalmatory_flat_data, 1078, "ico"}, //icon/excalmatory-flat.ico.c
#endif

	{ 0x98577B, (void*)_mgir_ico_excalmatory_data, 3638, "ico"}, //icon/excalmatory.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x975743, (void*)_mgir_ico_failed_flat_data, 1078, "ico"}, //icon/failed-flat.ico.c
#endif
	{ 0x191B83, (void*)_mgir_ico_failed_data, 3638, "ico"}, //icon/failed.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x977D73, (void*)_mgir_ico_folder_flat_data, 1078, "ico"}, //icon/folder-flat.ico.c
#endif

	{ 0x1931B3, (void*)_mgir_ico_folder_data, 1078, "ico"}, //icon/folder.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x4BF2B3, (void*)_mgir_ico_fold_flat_data, 1078, "ico"}, //icon/fold-flat.ico.c
#endif

	{ 0xCD4D3, (void*)_mgir_ico_fold_data, 1078, "ico"}, //icon/fold.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x4B0223, (void*)_mgir_ico_form_flat_data, 3638, "ico"}, //icon/form-flat.ico.c
#endif

	{ 0xC2443, (void*)_mgir_ico_form_data, 3638, "ico"}, //icon/form.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x4BCBA3, (void*)_mgir_ico_help_flat_data, 1078, "ico"}, //icon/help-flat.ico.c
#endif

	{ 0xCEDC3, (void*)_mgir_ico_help_data, 3638, "ico"}, //icon/help.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x12F9D03, (void*)_mgir_ico_textfile_flat_data, 1078, "ico"}, //icon/textfile-flat.ico.c
#endif

	{ 0x330483, (void*)_mgir_ico_textfile_data, 1078, "ico"}, //icon/textfile.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0x97F30B, (void*)_mgir_ico_unfold_flat_data, 1078, "ico"}, //icon/unfold-flat.ico.c
#endif

	{ 0x19BFCB, (void*)_mgir_ico_unfold_data, 1078, "ico"}, //icon/unfold.ico.c

#ifdef _MGLF_RDR_FLAT
	{ 0xC8AC63, (void*)_mgir_ico_warning_flat_data, 1078, "ico"}, //icon/warning-flat.ico.c
#endif

	{ 0x257123, (void*)_mgir_ico_warning_data, 3638, "ico"}, //icon/warning.ico.c
};

#endif // _MGINCORE_RES
